@@ -46,6 +46,19 @@ def download_gs_folder(bucket, gs_path, dst_path, client=client):
     print("DONE")
 
 
+def rename_blob(blob: storage.blob.Blob, new_name, client=client):
+    """Renames a blob."""
+    # bucket_name = "your-bucket-name"
+    # blob_name = "your-object-name"
+    # new_name = "new-object-name"
+
+    bucket = client.bucket(blob.bucket.name)
+
+    new_blob = bucket.rename_blob(blob, new_name)
+
+    print(f"Blob {blob.name} has been renamed to {new_blob.name}")
+
+
 def upload_blob(bucket_name, source_file_name, destination_blob_name, client=client):
     bucket = client.bucket(bucket_name)
     blob = bucket.blob(destination_blob_name)
